[cig-commits] r20254 - in cs/batlab: . trunk trunk/citcom/scripts trunk/citcom/scripts/svn trunk/gale trunk/gale/mount trunk/gale/scripts trunk/gale/scripts/svn trunk/gale/scripts/wget trunk/relax/scripts trunk/relax/scripts/wget trunk/specfem

alex at geodynamics.org alex at geodynamics.org
Thu May 31 16:30:05 PDT 2012


Author: alex
Date: 2012-05-31 16:30:05 -0700 (Thu, 31 May 2012)
New Revision: 20254

Added:
   cs/batlab/svn-commit.tmp
   cs/batlab/trunk/citcom/scripts/svn/svn-make.svn
   cs/batlab/trunk/gale/mount/wget-log
   cs/batlab/trunk/gale/mount/wgetInstallScript.sh
   cs/batlab/trunk/gale/scripts/
   cs/batlab/trunk/gale/scripts/README
   cs/batlab/trunk/gale/scripts/svn/
   cs/batlab/trunk/gale/scripts/svn/build.sh
   cs/batlab/trunk/gale/scripts/svn/hg-make.hg
   cs/batlab/trunk/gale/scripts/svn/run
   cs/batlab/trunk/gale/scripts/svn/simple-make.run-spec
   cs/batlab/trunk/gale/scripts/svn/simple-make.scp
   cs/batlab/trunk/gale/scripts/svn/svn-commit.2.tmp
   cs/batlab/trunk/gale/scripts/svn/svn-commit.tmp
   cs/batlab/trunk/gale/scripts/wget/
   cs/batlab/trunk/gale/scripts/wget/build.sh
   cs/batlab/trunk/gale/scripts/wget/generate_test_list.scp
   cs/batlab/trunk/gale/scripts/wget/generate_test_list.sh
   cs/batlab/trunk/gale/scripts/wget/run
   cs/batlab/trunk/gale/scripts/wget/run_test.scp
   cs/batlab/trunk/gale/scripts/wget/run_test.sh
   cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec
   cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.notest
   cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.test
   cs/batlab/trunk/gale/scripts/wget/simple-make.scp
   cs/batlab/trunk/gale/scripts/wget/web-make.url
   cs/batlab/trunk/gale/scripts/wgetInstallScript
   cs/batlab/trunk/mount/
   cs/batlab/trunk/relax/scripts/svn/
   cs/batlab/trunk/specfem/
   cs/batlab/trunk/specfem/mount/
Removed:
   cs/batlab/trunk/citcom/scripts/svn/generate_test_list.scp
   cs/batlab/trunk/citcom/scripts/svn/generate_test_list.sh
   cs/batlab/trunk/citcom/scripts/svn/reference1
   cs/batlab/trunk/citcom/scripts/svn/run_test.scp
   cs/batlab/trunk/citcom/scripts/svn/run_test.sh
   cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.notest
   cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.test
   cs/batlab/trunk/citcom/scripts/svn/web-make.url
   cs/batlab/trunk/relax/scripts/svn/
Modified:
   cs/batlab/README.txt
   cs/batlab/trunk/citcom/scripts/README.txt
   cs/batlab/trunk/citcom/scripts/svn/build.sh
   cs/batlab/trunk/citcom/scripts/svn/reference
   cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec
   cs/batlab/trunk/relax/scripts/README
   cs/batlab/trunk/relax/scripts/wget/build.sh
   cs/batlab/trunk/relax/scripts/wget/simple-make.run-spec
   cs/batlab/trunk/relax/scripts/wget/web-make.url
Log:
relax is done, though some older versions of fortran aren't working.
citcom is done, though we are still waiting on batlab's mpi
starting work on specfem

NOTE: batlab only has x86_64 processors.  We may implement our own testing lab to test amd or 32-bit chip architectures



Modified: cs/batlab/README.txt
===================================================================
--- cs/batlab/README.txt	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/README.txt	2012-05-31 23:30:05 UTC (rev 20254)
@@ -13,3 +13,5 @@
 /cig/cs/batlab/trunk/projectDir/scripts/
 each scripts directory should have it's own README to describe the info/structure in the scripts.
 /cig/cs/batlab/trunk/citcom/scripts/wgetInstall script was used for local testing.  It is written in bash and is not necessarily compatible with the batlab structure.  However, much of the code was copied into build.sh to build batlab scripts and for that reason it remains, in case more code needs to be copied or restored.
+
+Gale is no longer needed for testing, as there isn't much dev work going on for the program.

Added: cs/batlab/svn-commit.tmp
===================================================================
--- cs/batlab/svn-commit.tmp	                        (rev 0)
+++ cs/batlab/svn-commit.tmp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,5 @@
+citcom is done, but waiting on mpi still
+relax is done, but some platforms with older versions of gfortran are missing.
+starting work on specfem
+
+NOTE: currently the batlab only has x86_64 platforms available.  We may create our own batlab to test AMD chip architectures and 32 bit architectures.
\ No newline at end of file

Modified: cs/batlab/trunk/citcom/scripts/README.txt
===================================================================
--- cs/batlab/trunk/citcom/scripts/README.txt	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/README.txt	2012-05-31 23:30:05 UTC (rev 20254)
@@ -5,3 +5,5 @@
 wget scripts may be copies of svn scripts, but haven't been updated as they are low priority and were used as preliminary tests
 
 svn script build.sh contains not only the instructions for installation and compilation, but tests with debugging markers, which show up in the batlab error messages.  If there is a problem, notification emails are sent out to emails listed in svn/simple-make.run-spec
+
+Currently, the scripts run once a day at midnight.  

Modified: cs/batlab/trunk/citcom/scripts/svn/build.sh
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/generate_test_list.scp	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/generate_test_list.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,2 +0,0 @@
-method = scp
-scp_file = ~/scripts/generate_test_list.sh
\ No newline at end of file

Deleted: cs/batlab/trunk/citcom/scripts/svn/generate_test_list.sh
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/generate_test_list.sh	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/generate_test_list.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,10 +0,0 @@
-#!/bin/bash
-# cd CitcomS-* ## this is for wget
-cd CitcomS			# this is for svn
-cd examples/Regional/
-# make the input.sample file work
-sed -i 's|datadir="/scratch"|datadir="./scratch"|g' input.sample 
-sed -i 's|nprocx=2|nprocx=1|g' input.sample
-sed -i 's|nprocy=2|nprocy=1|g' input.sample
-# now test - we only want to compare heat flux (surface/bottom)
-../../bin/CitcomSRegional input.sample 2>&1 | grep flux > ../tasklist.nmi
\ No newline at end of file

Modified: cs/batlab/trunk/citcom/scripts/svn/reference
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/reference	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/reference	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,16 +1,16 @@
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
-1
\ No newline at end of file
+2.223612
+2.175360
+1.855250
+2.764555
+1.550088
+3.512788
+2.038765
+5.534696
+3.670634
+8.582555
+5.885579
+11.877412
+8.006005
+14.699923
+9.478705
+16.633825

Deleted: cs/batlab/trunk/citcom/scripts/svn/reference1
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/reference1	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/reference1	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,16 +0,0 @@
-2.223612
-2.175360
-1.855250
-2.764555
-1.550088
-3.512788
-2.038765
-5.534696
-3.670634
-8.582555
-5.885579
-11.877412
-8.006005
-14.699923
-9.478705
-16.633825

Deleted: cs/batlab/trunk/citcom/scripts/svn/run_test.scp
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/run_test.scp	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/run_test.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,2 +0,0 @@
-method = scp
-scp_file = ~/scripts/run_test.sh
\ No newline at end of file

Deleted: cs/batlab/trunk/citcom/scripts/svn/run_test.sh
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/run_test.sh	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/run_test.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,6 +0,0 @@
-#!/bin/bash
-
-#cd CitcomS-*  ## this is for wget
-cd CitcomS 			# this is svn
-cd examples/Regional/
-../../bin/CitcomSRegional input.sample
\ No newline at end of file

Modified: cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,6 +1,10 @@
+project = cig
 run_type = build
-inputs = simple-make.scp, web-make.url
+inputs = simple-make.scp, svn-make.svn
 remote_task = build.sh
-platforms = x86_64_ubuntu_10.04.4, x86_64_deb_5.0, x86_64_sol_5.11, x86_64_rhap_5.7, x86_64_rhap_6.2, x86_64_sl_6.2, x86_64_winnt_6.1, x86_64_deb_6.0, x86_sl_5.8, x86_winnt_5.1, x86_64_opensuse_11.4, x86_64_opensuse_11.3, x86_64_macos_10.7, x86_64_freebsd_8.2, x86_64_fedora_16, x86_64_fedora_15, x86_64_deb_6.0
+platforms = x86_64_ubuntu_10.04.4, x86_64_sol_5.11, x86_64_rhap_6.2, x86_64_sl_6.2, x86_64_deb_6.0, x86_64_macos_10.7, x86_freebsd_7.4, x86_64_fedora_16, x86_64_fedora_15, x86_64_deb_5.0, x86_64_macos_10.7, x86_64_opensuse_11.4, x86_64_rhap_5.7, x86_sl_5.8
 
-notify = alex at geodynamics.org, emheien at geodynamics.org
+cron_hour = 0
+cron_minute = 0
+
+notify = alex at geodynamics.org, emheien at geodynamics.org
\ No newline at end of file

Deleted: cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.notest
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.notest	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.notest	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,4 +0,0 @@
-run_type = build
-inputs = simple-make.scp, web-make.url
-remote_task = build.sh
-platforms = x86_64_ubuntu_10.04.4

Deleted: cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.test
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.test	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/simple-make.run-spec.test	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,8 +0,0 @@
-run_type = build
-inputs = simple-make.scp, web-make.url, run_test.scp, generate_test_list.scp
-remote_task = build.sh
-platforms = x86_64_ubuntu_10.04.4
-
-remote_pre_declare = build.sh
-remote_declare = generate_test_list.sh
-remote_task = run_test.sh

Added: cs/batlab/trunk/citcom/scripts/svn/svn-make.svn
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/svn-make.svn	                        (rev 0)
+++ cs/batlab/trunk/citcom/scripts/svn/svn-make.svn	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,6 @@
+method = svn
+url = http://geodynamics.org/svn/cig/mc/3D/CitcomS/trunk CitcomS
+
+# method = url
+# url = www.geodynamics.org/cig/software/citcoms/CitcomS-3.2.0.tar.gz
+# untar = true
\ No newline at end of file

Deleted: cs/batlab/trunk/citcom/scripts/svn/web-make.url
===================================================================
--- cs/batlab/trunk/citcom/scripts/svn/web-make.url	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/web-make.url	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,6 +0,0 @@
-method = svn
-url = http://geodynamics.org/svn/cig/mc/3D/CitcomS/trunk CitcomS
-
-# method = url
-# url = www.geodynamics.org/cig/software/citcoms/CitcomS-3.2.0.tar.gz
-# untar = true
\ No newline at end of file

Added: cs/batlab/trunk/gale/mount/wget-log
===================================================================
--- cs/batlab/trunk/gale/mount/wget-log	                        (rev 0)
+++ cs/batlab/trunk/gale/mount/wget-log	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,85 @@
+--2012-03-22 16:10:59--  http://www.geodynamics.org/cig/software/gale/Gale-Linux64-2_0_0.tgz
+Resolving www.geodynamics.org... 128.120.246.102
+Connecting to www.geodynamics.org|128.120.246.102|:80... connected.
+HTTP request sent, awaiting response... 200 OK
+Length: 10662476 (10M) [application/x-tar]
+Saving to: `Gale-Linux64-2_0_0.tgz.1'
+
+
+55% [==========================>                      ] 5,902,560    311K/s  eta 15s     
+55% [==========================>                      ] 5,965,920    310K/s  eta 15s     
+56% [==========================>                      ] 6,030,720    311K/s  eta 15s     
+57% [===========================>                     ] 6,095,520    311K/s  eta 15s     
+57% [===========================>                     ] 6,160,320    311K/s  eta 14s     
+58% [===========================>                     ] 6,225,120    311K/s  eta 14s     
+58% [===========================>                     ] 6,289,920    311K/s  eta 14s     
+59% [============================>                    ] 6,353,280    311K/s  eta 14s     
+60% [============================>                    ] 6,416,640    311K/s  eta 14s     
+60% [============================>                    ] 6,481,440    311K/s  eta 13s     
+61% [=============================>                   ] 6,546,240    311K/s  eta 13s     
+62% [=============================>                   ] 6,611,040    311K/s  eta 13s     
+62% [=============================>                   ] 6,675,840    311K/s  eta 13s     
+63% [=============================>                   ] 6,740,640    311K/s  eta 13s     
+63% [==============================>                  ] 6,805,440    311K/s  eta 12s     
+64% [==============================>                  ] 6,870,240    311K/s  eta 12s     
+65% [==============================>                  ] 6,935,040    311K/s  eta 12s     
+65% [===============================>                 ] 6,999,840    311K/s  eta 12s     
+66% [===============================>                 ] 7,064,640    311K/s  eta 12s     
+66% [===============================>                 ] 7,129,440    311K/s  eta 11s     
+67% [================================>                ] 7,194,240    311K/s  eta 11s     
+67% [================================>                ] 7,245,184    298K/s  eta 11s     
+68% [================================>                ] 7,349,760    311K/s  eta 11s     
+69% [=================================>               ] 7,414,560    311K/s  eta 11s     
+70% [=================================>               ] 7,479,360    311K/s  eta 10s     
+70% [=================================>               ] 7,544,160    311K/s  eta 10s     
+71% [=================================>               ] 7,608,960    311K/s  eta 10s     
+71% [==================================>              ] 7,673,760    311K/s  eta 10s     
+72% [==================================>              ] 7,738,560    311K/s  eta 10s     
+73% [==================================>              ] 7,803,360    311K/s  eta 9s      
+73% [===================================>             ] 7,868,160    311K/s  eta 9s      
+74% [===================================>             ] 7,932,960    311K/s  eta 9s      
+75% [===================================>             ] 7,997,760    311K/s  eta 9s      
+75% [====================================>            ] 8,062,560    311K/s  eta 9s      
+76% [====================================>            ] 8,127,360    311K/s  eta 8s      
+76% [====================================>            ] 8,192,160    311K/s  eta 8s      
+77% [====================================>            ] 8,256,960    311K/s  eta 8s      
+78% [=====================================>           ] 8,320,320    311K/s  eta 8s      
+78% [=====================================>           ] 8,385,120    311K/s  eta 8s      
+79% [=====================================>           ] 8,449,920    311K/s  eta 7s      
+79% [======================================>          ] 8,514,720    311K/s  eta 7s      
+80% [======================================>          ] 8,579,520    311K/s  eta 7s      
+81% [======================================>          ] 8,642,880    311K/s  eta 7s      
+81% [=======================================>         ] 8,706,240    310K/s  eta 7s      
+82% [=======================================>         ] 8,771,040    310K/s  eta 6s      
+82% [=======================================>         ] 8,835,840    310K/s  eta 6s      
+83% [=======================================>         ] 8,900,640    310K/s  eta 6s      
+84% [========================================>        ] 8,965,440    311K/s  eta 6s      
+84% [========================================>        ] 9,030,240    311K/s  eta 6s      
+84% [========================================>        ] 9,052,384    298K/s  eta 5s      
+85% [=========================================>       ] 9,159,840    311K/s  eta 5s      
+86% [=========================================>       ] 9,223,200    310K/s  eta 5s      
+87% [=========================================>       ] 9,288,000    311K/s  eta 5s      
+87% [=========================================>       ] 9,352,800    311K/s  eta 5s      
+88% [==========================================>      ] 9,417,600    311K/s  eta 4s      
+88% [==========================================>      ] 9,482,400    311K/s  eta 4s      
+89% [==========================================>      ] 9,545,760    310K/s  eta 4s      
+90% [===========================================>     ] 9,610,560    311K/s  eta 4s      
+90% [===========================================>     ] 9,675,360    311K/s  eta 4s      
+91% [===========================================>     ] 9,740,160    311K/s  eta 3s      
+91% [============================================>    ] 9,804,960    311K/s  eta 3s      
+92% [============================================>    ] 9,869,760    311K/s  eta 3s      
+93% [============================================>    ] 9,934,560    311K/s  eta 3s      
+93% [============================================>    ] 9,999,360    311K/s  eta 3s      
+94% [=============================================>   ] 10,064,160   311K/s  eta 2s      
+94% [=============================================>   ] 10,128,960   311K/s  eta 2s      
+95% [=============================================>   ] 10,193,760   311K/s  eta 2s      
+96% [==============================================>  ] 10,258,560   312K/s  eta 2s      
+96% [==============================================>  ] 10,323,360   311K/s  eta 2s      
+97% [==============================================>  ] 10,388,160   311K/s  eta 1s      
+98% [===============================================> ] 10,452,960   311K/s  eta 1s      
+98% [===============================================> ] 10,517,760   311K/s  eta 1s      
+99% [===============================================> ] 10,577,344   299K/s  eta 1s      
+100%[================================================>] 10,662,476   311K/s   in 34s     
+
+2012-03-22 16:11:35 (309 KB/s) - `Gale-Linux64-2_0_0.tgz.1' saved [10662476/10662476]
+

Added: cs/batlab/trunk/gale/mount/wgetInstallScript.sh
===================================================================
--- cs/batlab/trunk/gale/mount/wgetInstallScript.sh	                        (rev 0)
+++ cs/batlab/trunk/gale/mount/wgetInstallScript.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,42 @@
+#!/bin/bash
+
+# set up directories
+
+currentVersion=Gale-Linux64-2_0_0
+galeDirectory=/home/at/gale
+wgetLogFile=/home/at/gale/wgetLogFile
+configureLogFile=/home/at/gale/$currentVersion/configureLogFile
+makeLogFile=/home/at/gale/$currentVersion/makeLogFile
+#testLogFile=$galeDirectory/$currentVersion/examples/Cookbook1/testLogFile
+webAddress=www.geodynamics.org/cig/software/gale
+gale=$currentVersion.tgz
+# cookbooks=$galeDirectory/examples/
+
+# clean up to prepare for install
+
+cd $galeDirectory/
+# rm -r CitcomS-*
+# mpd&				# run mpd in background ##todo shut off mpd after this is finished, and ignore error here if there's a prolllem
+
+set -e				# kills program if there's an error
+
+# download, unpack, remove zip
+wget -r --output-file=$wgetLogFile --output-document=$galeDirectory/$gale $webAddress/$gale
+tar -xzvf $galeDirectory/$gale
+rm $galeDirectory/$gale
+mv $wgetLogFile $galeDirectory/$currentVersion/
+
+cd $currentVersion/
+
+# configure and make
+./configure --without-pyre >> $configureLogFile
+make >> $makeLogFile
+
+# test Regional input.sample
+cd $galeDirectory/$currentVersion/examples/Regional/
+# update the input.sample file to work
+sed -i 's|datadir="/scratch"|datadir="./scratch"|g' input.sample 
+sed -i 's|nprocx=2|nprocx=1|g' input.sample
+sed -i 's|nprocy=2|nprocy=1|g' input.sample
+$galeDirectory/$currentVersion/bin/CitcomSRegional input.sample >> testLogFile
+

Added: cs/batlab/trunk/gale/scripts/README
===================================================================
--- cs/batlab/trunk/gale/scripts/README	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/README	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,5 @@
+svn uses mercury (hg) and batlab doesn't seem to support it.  
+Thus, we are using wget scripts to download relax onto the test nodes.
+Note:  the svn directory is still set up to run the tests.
+
+The build.sh script has the test in it as well, it runs relax, finds the power in the 009 iteration and tests that agains the reference value 7.72E-01.  If there is a problem, it sends an email.
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/svn/build.sh
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/build.sh	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/build.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,71 @@
+#!/bin/sh
+#
+# We don't proceed unless the preceding step succeeded, and we return the success or failure of the sequence.
+#should already be untarred from the wget script.
+
+# update gale to latest version from repos
+cd gale
+hg pull
+hg up
+cd PICellerator
+hg pull
+hg up
+cd ../StGermain
+hg pull
+hg up
+cd ../StgDomain
+hg pull
+hg up
+cd ../StgFEM
+hg pull
+hg up
+cd ../Underworld
+hg pull
+hg up
+cd ../config
+hg pull
+hg up
+cd ../gLucifer
+hg pull
+hg up
+
+# build and test program
+# need to replace run1.input to either test only first coseismic event, or limit integration to a certain number of iterations
+# grep records only the tenth iteration on the first coseismic event, puts it in results
+cd ../gale
+./waf configure --use-fftw \
+    && ./waf \
+    && cd examples \
+    && ../build/gale $* < ../../../run1.input | grep -e "009* " -m1 | tee results
+# stop after 10 runs, and test the power numbers
+
+
+if [ $? != 0 ]			
+then
+    echo "problem building and testing"
+    exit 1
+fi
+
+# run a script to parse the file input and to determine whether an email needs to be sent
+val=`cut -f 7 -d " " results`	# store power result from iteration 009 in val
+email=0				# default to not send email
+
+echo "this is val: $val"	# debugging
+if [ $val != 7.72E-01 ]		# 7.72E-01 is power reading from benchmarks for coseismic event 1, iteration 009
+then
+    email=$c;	# we need to send an email
+    echo "$val is the power at iteration 009 of coseismic event 1, instead of 7.72E-01" >> errors 
+fi
+done
+
+# append the hostname and date to the results file
+hostname >> errors \
+    && date >> errors
+
+# send an email if it needs to be sent with the power data, platform, and date
+if [ $email != 0 ]
+then
+    cat errors | mailx -s ErrorOverBound alex at geodynamics.org, emheien at geodynamics.org    # send email containing errors
+fi
+
+exit $?
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/svn/build.sh
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/svn/hg-make.hg
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/hg-make.hg	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/hg-make.hg	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,13 @@
+method = hg
+url = http://geodynamics.org/hg/short/3D/relax relax
+url = http://geodynamics.org/hg/long/3D/gale/PICellerator gale/PICellerator
+url = http://geodynamics.org/hg/long/3D/gale/StGermain gale/StGermain
+url = http://geodynamics.org/hg/long/3D/gale/StgDomain gale/StgDomain
+url = http://geodynamics.org/hg/long/3D/gale/StgFEM gale/StgFEM
+url = http://geodynamics.org/hg/long/3D/gale/Underworld gale/Underworld
+url = http://geodynamics.org/hg/long/3D/gale/config gale/config
+url = http://geodynamics.org/hg/long/3D/gale/gLucifer gale/gLucifer
+
+# method = url
+# url = www.geodynamics.org/cig/software/citcoms/CitcomS-3.2.0.tar.gz
+# untar = true
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/svn/run
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/run	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/run	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,2 @@
+#!/bin/sh
+nmi_submit ~/scripts/simple-make.run-spec
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/svn/run
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/svn/simple-make.run-spec
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/simple-make.run-spec	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/simple-make.run-spec	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,6 @@
+run_type = build
+inputs = simple-make.scp, hg-make.hg
+remote_task = build.sh
+platforms = x86_64_ubuntu_10.04.4, x86_64_deb_5.0, x86_64_sol_5.11, x86_64_rhap_5.7, x86_64_rhap_6.2, x86_64_sl_6.2, x86_64_winnt_6.1, x86_64_deb_6.0, x86_sl_5.8, x86_winnt_5.1, x86_64_opensuse_11.4, x86_64_opensuse_11.3, x86_64_macos_10.7, x86_64_freebsd_8.2, x86_64_fedora_16, x86_64_fedora_15, x86_64_deb_6.0
+
+notify = alex at geodynamics.org, emheien at geodynamics.org

Added: cs/batlab/trunk/gale/scripts/svn/simple-make.scp
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/simple-make.scp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/simple-make.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,3 @@
+method = scp
+scp_file = ~/scripts/build.sh
+recursive = true
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/svn/svn-commit.2.tmp
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/svn-commit.2.tmp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/svn-commit.2.tmp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,15 @@
+citcom done (still waiting on mpi)
+starting relax for hg(svn).  svn directory updated with build.sh test
+
+--This line, and those below, will be ignored--
+
+M    simple-make.run-spec
+A    hg-make.hg
+D    run_test.scp
+M    build.sh
+D    generate_test_list.scp
+D    web-make.url
+D    simple-make.run-spec.notest
+D    run_test.sh
+D    generate_test_list.sh
+D    simple-make.run-spec.test

Added: cs/batlab/trunk/gale/scripts/svn/svn-commit.tmp
===================================================================
--- cs/batlab/trunk/gale/scripts/svn/svn-commit.tmp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/svn/svn-commit.tmp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,14 @@
+citcom done (still waiting on mpi)
+starting testing for svn(hg) on relax
+--This line, and those below, will be ignored--
+
+M    simple-make.run-spec
+A    hg-make.hg
+D    run_test.scp
+M    build.sh
+D    generate_test_list.scp
+D    web-make.url
+D    simple-make.run-spec.notest
+D    run_test.sh
+D    generate_test_list.sh
+D    simple-make.run-spec.test

Added: cs/batlab/trunk/gale/scripts/wget/build.sh
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/build.sh	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/build.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,56 @@
+#!/bin/sh
+#
+# We don't proceed unless the preceding step succeeded, and we return the success or failure of the sequence.
+#should already be untarred from the wget script.
+
+# download gmt libraries and install
+wget  ftp://ftp.iris.washington.edu/pub/gmt/gmt-4.5.8.tar.bz2
+tar xvjf gmt-4.5.8.tar.bz2
+# install gmt libraries
+cd GMT* \
+    && ./configure --without-x\
+    && make \
+    && make install-gmt \
+    && make install-data \
+    && make clean
+
+# build and test program
+# need to replace run1.input to either test only first coseismic event, or limit integration to a certain number of iterations
+# grep records only the tenth iteration on the first coseismic event, puts it in results
+cd ../relax-*  
+./waf configure --use-fftw --zero-flag=-ffree-line-length-none \
+    && ./waf \
+    && cd examples \
+    && ../build/relax $* < run1.input | grep -e "009* " -m1 | tee results
+# stop after 10 runs, and test the power numbers
+
+
+if [ $? != 0 ]			
+then
+    echo "problem building and testing"
+    exit 1
+fi
+
+# run a script to parse the file input and to determine whether an email needs to be sent
+val=`cut -f 7 -d " " results`	# store power result from iteration 009 in val
+email=0				# default to not send email
+
+echo "this is val: $val"	# debugging
+if [ $val != 7.72E-01 ]		# 7.72E-01 is power reading from benchmarks for coseismic event 1, iteration 009
+then
+    email=$c;	# we need to send an email
+    echo "$val is the power at iteration 009 of coseismic event 1, instead of 7.72E-01" >> errors 
+fi
+done
+
+# append the hostname and date to the results file
+hostname >> errors \
+    && date >> errors
+
+# send an email if it needs to be sent with the power data, platform, and date
+if [ $email != 0 ]
+then
+    cat errors | mailx -s ErrorOverBound alex at geodynamics.org, emheien at geodynamics.org    # send email containing errors
+fi
+
+exit $?
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/wget/build.sh
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/wget/generate_test_list.scp
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/generate_test_list.scp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/generate_test_list.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,2 @@
+method = scp
+scp_file = ~/scripts/generate_test_list.
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wget/generate_test_list.sh
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/generate_test_list.sh	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/generate_test_list.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,11 @@
+#!/bin/bash
+cd CitcomS-*
+cd examples/Regional/
+# make the input.sample file work
+sed -i 's|datadir="/scratch"|datadir="./scratch"|g' input.sample 
+sed -i 's|nprocx=2|nprocx=1|g' input.sample
+sed -i 's|nprocy=2|nprocy=1|g' input.sample
+# now test
+../../bin/CitcomSRegional | \
+    tail -n +3 | \
+    awk '{print $3}' > ../tasklist.nmi
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/wget/generate_test_list.sh
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/wget/run
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/run	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/run	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,2 @@
+#!/bin/sh
+nmi_submit ~/scripts/simple-make.run-spec
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/wget/run
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/wget/run_test.scp
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/run_test.scp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/run_test.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,2 @@
+method = scp
+scp_file = ~/scripts/run_test.sh
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wget/run_test.sh
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/run_test.sh	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/run_test.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,5 @@
+#!/bin/bash
+
+cd relax-* 
+cd examples/Regional/
+../../bin/CitcomSRegional input.sample
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/wget/run_test.sh
___________________________________________________________________
Name: svn:executable
   + *

Added: cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,6 @@
+run_type = build
+inputs = simple-make.scp, web-make.url
+remote_task = build.sh
+platforms = x86_64_ubuntu_10.04.4, x86_64_deb_5.0, x86_64_sol_5.11, x86_64_rhap_5.7, x86_64_rhap_6.2, x86_64_sl_6.2, x86_64_winnt_6.1, x86_64_deb_6.0, x86_sl_5.8, x86_winnt_5.1, x86_64_opensuse_11.4, x86_64_opensuse_11.3, x86_64_macos_10.7, x86_64_freebsd_8.2, x86_64_fedora_16, x86_64_fedora_15, x86_64_deb_6.0
+
+notify = alex at geodynamics.org, emheien at geodynamics.org

Added: cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.notest
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.notest	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.notest	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,13 @@
+run_type = build
+inputs = simple-make.scp, web-make.url
+remote_task = build.sh
+platforms = x86_64_ubuntu_10.04
+
+remote_pre_declare = build.sh
+remote_declare = generate_test_list.sh
+
+
+cron_hour = 13
+cron_minute=11
+
+notify = alextakakuwa at gmail.com
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.test
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.test	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/simple-make.run-spec.test	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,13 @@
+run_type = build
+inputs = simple-make.scp, web-make.url, run_test.scp, generate_test_list.sh
+remote_task = build.sh
+platforms = x86_64_ubuntu_10.04
+
+remote_pre_declare = build.sh
+remote_declare = generate_test_list.sh
+remote_task = run_test.sh
+
+cron_hour = 13
+cron_minute=11
+
+notify = alextakakuwa at gmail.com
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wget/simple-make.scp
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/simple-make.scp	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/simple-make.scp	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,3 @@
+method = scp
+scp_file = ~/scripts/build.sh
+recursive = true
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wget/web-make.url
===================================================================
--- cs/batlab/trunk/gale/scripts/wget/web-make.url	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wget/web-make.url	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,3 @@
+method = url
+url = www.geodynamics.org/cig/software/relax/Relax-1.0.1.tgz
+untar = true
\ No newline at end of file

Added: cs/batlab/trunk/gale/scripts/wgetInstallScript
===================================================================
--- cs/batlab/trunk/gale/scripts/wgetInstallScript	                        (rev 0)
+++ cs/batlab/trunk/gale/scripts/wgetInstallScript	2012-05-31 23:30:05 UTC (rev 20254)
@@ -0,0 +1,41 @@
+#!/bin/bash
+
+# set up directories
+
+currentVersion=CitcomS-3.2.0
+cigDirectory=/home/at/cig
+wgetLogFile=/home/at/cig/wgetLogFile
+configureLogFile=/home/at/cig/$currentVersion/configureLogFile
+makeLogFile=/home/at/cig/$currentVersion/makeLogFile
+testLogFile=$cigDirectory/$currentVersion/examples/Cookbook1/testLogFile
+webAddress=www.geodynamics.org/cig/software/citcoms
+citcomS=$currentVersion.tar.gz
+cookbooks=$cigDirectory/examples/
+
+# clean up to prepare for install
+
+cd $cigDirectory/
+rm -r CitcomS-*
+mpd&				# run mpd in background ##todo shut off mpd after this is finished, and ignore error here if there's a prolllem
+
+set -e				# kills program if there's an error
+
+# download, unpack, remove zip
+wget -r --output-file=$wgetLogFile --output-document=$cigDirectory/$citcomS $webAddress/$citcomS
+tar -xzvf $cigDirectory/$citcomS
+rm $cigDirectory/$citcomS
+mv $wgetLogFile $cigDirectory/$currentVersion/
+
+cd $currentVersion/
+
+# configure and make
+./configure --without-pyre >> $configureLogFile
+make >> $makeLogFile
+
+# test Regional input.sample
+cd $cigDirectory/$currentVersion/examples/Regional/
+# update the input.sample file to work
+sed -i 's|datadir="/scratch"|datadir="./scratch"|g' input.sample 
+sed -i 's|nprocx=2|nprocx=1|g' input.sample
+sed -i 's|nprocy=2|nprocy=1|g' input.sample
+$cigDirectory/$currentVersion/bin/CitcomSRegional input.sample >> testLogFile
\ No newline at end of file


Property changes on: cs/batlab/trunk/gale/scripts/wgetInstallScript
___________________________________________________________________
Name: svn:executable
   + *

Modified: cs/batlab/trunk/relax/scripts/README
===================================================================
--- cs/batlab/trunk/relax/scripts/README	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/relax/scripts/README	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,2 +1,3 @@
-svn uses mercury (hg) and batlab doesn't seem to support it.  
-Thus, we are using wget scripts to download relax onto the test nodes.
\ No newline at end of file
+Relax uses mercurial (hg).
+
+The build.sh script has the test in it as well, it runs relax, finds the power in the 009 iteration and tests that agains the reference value 7.72E-01.  If there is a problem, it sends an email.
\ No newline at end of file

Modified: cs/batlab/trunk/relax/scripts/wget/build.sh
===================================================================
--- cs/batlab/trunk/relax/scripts/wget/build.sh	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/relax/scripts/wget/build.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -2,11 +2,55 @@
 #
 # We don't proceed unless the preceding step succeeded, and we return the success or failure of the sequence.
 #should already be untarred from the wget script.
-cd relax-*  
-./waf configure \
-    && ./waf \ 
+
+# download gmt libraries and install
+wget  ftp://ftp.iris.washington.edu/pub/gmt/gmt-4.5.8.tar.bz2
+tar xvjf gmt-4.5.8.tar.bz2
+# install gmt libraries
+cd GMT* \
+    && ./configure --without-x\
     && make \
-    && cd .. \
-    && tar -c -z -f ./results.tar.gz ./install
+    && make install-gmt \
+    && make install-data \
+    && make clean
 
+# build and test program
+# need to replace run1.input to either test only first coseismic event, or limit integration to a certain number of iterations
+# grep records only the tenth iteration on the first coseismic event, puts it in results
+cd ../relax-*  
+./waf configure --use-fftw --zero-flag=-ffree-line-length-none \
+    && ./waf \
+    && cd examples \
+    && ../build/relax $* < run1.input | grep -e "009* " -m1 | tee results
+# stop after 10 runs, and test the power numbers
+
+
+if [ $? != 0 ]			
+then
+    echo "problem building and testing"
+    exit 1
+fi
+
+# run a script to parse the file input and to determine whether an email needs to be sent
+val=`cut -f 7 -d " " results`	# store power result from iteration 009 in val
+email=0				# default to not send email
+
+echo "this is val: $val"	# debugging
+if [ $val != 7.72E-01 ]		# 7.72E-01 is power reading from benchmarks for coseismic event 1, iteration 009
+then
+    email=$c;	# we need to send an email
+    echo "$val is the power at iteration 009 of coseismic event 1, instead of 7.72E-01" >> errors 
+fi
+done
+
+# append the hostname and date to the results file
+hostname >> errors \
+    && date >> errors
+
+# send an email if it needs to be sent with the power data, platform, and date
+if [ $email != 0 ]
+then
+    cat errors | mailx -s ErrorOverBound alex at geodynamics.org, emheien at geodynamics.org    # send email containing errors
+fi
+
 exit $?
\ No newline at end of file

Modified: cs/batlab/trunk/relax/scripts/wget/simple-make.run-spec
===================================================================
--- cs/batlab/trunk/relax/scripts/wget/simple-make.run-spec	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/relax/scripts/wget/simple-make.run-spec	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,13 +1,6 @@
 run_type = build
 inputs = simple-make.scp, web-make.url
 remote_task = build.sh
-platforms = x86_64_ubuntu_10.04
+platforms = x86_64_ubuntu_10.04.4, x86_64_deb_5.0, x86_64_sol_5.11, x86_64_rhap_5.7, x86_64_rhap_6.2, x86_64_sl_6.2, x86_64_winnt_6.1, x86_64_deb_6.0, x86_sl_5.8, x86_winnt_5.1, x86_64_opensuse_11.4, x86_64_opensuse_11.3, x86_64_macos_10.7, x86_64_freebsd_8.2, x86_64_fedora_16, x86_64_fedora_15, x86_64_deb_6.0
 
-remote_pre_declare = build.sh
-remote_declare = generate_test_list.sh
-
-
-cron_hour = 13
-cron_minute=11
-
-notify = alextakakuwa at gmail.com
\ No newline at end of file
+notify = alex at geodynamics.org, emheien at geodynamics.org

Modified: cs/batlab/trunk/relax/scripts/wget/web-make.url
===================================================================
--- cs/batlab/trunk/relax/scripts/wget/web-make.url	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/relax/scripts/wget/web-make.url	2012-05-31 23:30:05 UTC (rev 20254)
@@ -1,3 +1,3 @@
 method = url
-url = http://www.geodynamics.org/cig/software/relax/Relax-1.0.0.tgz
+url = www.geodynamics.org/cig/software/relax/Relax-1.0.1.tgz
 untar = true
\ No newline at end of file



More information about the CIG-COMMITS mailing list
--- cs/batlab/trunk/citcom/scripts/svn/build.sh	2012-05-31 23:00:33 UTC (rev 20253)
+++ cs/batlab/trunk/citcom/scripts/svn/build.sh	2012-05-31 23:30:05 UTC (rev 20254)
@@ -20,41 +20,36 @@
 then
     echo "problem building and testing"
     exit 1
- fi
+fi
 
-
 # run a script to parse the file input and to determine whether an email needs to be sent
-cut -f 4 -d " " flux.txt > test
-length=`cat test | wc -l`
+cut -f 4 -d " " flux.txt > temp
+length=`cat temp | wc -l`
 email=0				# default to not send email
 
+# create a file of the absolute value of the percentage differences, multiplied by 100000
+paste temp ../../../reference | awk '{diff=($1-$2)/$2*100000; if(diff<0) diff=-diff; printf "%1.0f\n", diff}' > test 
+
 for ((c=1; c<=$length; c++))
 do
-    val1=`head -n $c test | tail -n 1`
-    val2=`head -n $c ../../../reference | tail -n 1`
-    diff=`echo "($val1-$val2)/$val2*100000" | bc -l`
-    echo $diff			# debugging
-    int=`echo $diff | cut -f 1 -d "."`
-    echo $int			# debugging
-    echo " "			# debugging
-    if [ `echo $int` -gt 1 ]	# added echo to solve "-gt unary operator expected"
+    val=`head -n $c test | tail -n 1`
+    echo "this is diff: $val"	# debugging
+    if [ $val -gt 1 ] 
     then
 	email=$c;	# we need to send an email
-	echo " "	# debugging
-	echo "problem at line $c of flux script" # debugging
-	echo $c		# debugging
-	echo " "	# debugging
+	echo "problem at line $c of flux results" >> errors 
     fi
 done
 
 # append the hostname to the flux file, and return it to the user if he/she so desires it
 hostname >> flux.txt \
-    && echo $email >> flux.txt
+&& cat errors >> flux.txt \
+    && date >> flux.txt
 
 # send an email if it needs to be sent with the flux data, platform, and line of last error
 if [ $email != 0 ]
 then
-    echo "" | mailx -s ErrorOverBound -a flux.txt alex at geodynamics.org    # send email with flux.txt attached.
- fi
+    cat flux.txt | mailx -s ErrorOverBound alex at geodynamics.org, emheien at geodynamics.org    # send email containing flux.txt
+fi
 
 exit $?
\ No newline at end of file
@@ -20,41 +20,36 @@
 done
 
-# append the hostname to the flux file, and return it to the user if he/she so desires it
+# append the hostname to the flux file, append the errors, and append the date and time of the run.
 hostname >> flux.txt \
@@ -20,41 +20,36 @@
 
-# send an email if it needs to be sent with the flux data, platform, and line of last error
+# send an email if it needs to be sent with the flux data, platform/date, and lines containing errors
 if [ $email != 0 ]
 then

Deleted: cs/batlab/trunk/citcom/scripts/svn/generate_test_list.scp
===================================================================